@@ -5,15 +5,14 @@ import json
 import string
 import os
 
-from cvapianalyser.CVApiAnalyser import CVApiAnalyser
-from cvapianalyser.CommunityEdition import CommunityEdition
-from openapispecdiff.OpenApiSpecDiff import OpenApiSpecDiff
+from cvapianalyser import CommunityEdition
+from openapispecdiff import OpenApiSpecDiff
 
 class CVTrafficRegenerator(object):
     def __init__(self, APISpecOne, APISpecTwo, ce_host, ce_username, ce_password):
         self.apispec_one_path = APISpecOne
         self.apispec_two_path = APISpecTwo
-        self.ceobj = CommunityEdition("http://" + ce_host, ce_username, ce_password)
+        self.ceobj = CommunityEdition.CommunityEdition("http://" + ce_host, ce_username, ce_password)
         print("\n\t\t\t\t\t\t\t\t\t----------------- Traffic Regeneator - For CloudVector APIShark events "
                                                                                                     "-----------------")
         self.regenerate_traffic(self._get_changed_apis())
